base_cdf plots an empirical cdf of the toxicity values against one or
several fitted distributions' cdf. It works for both censored and non
censored data.
base_cdf(fits, unit, logscale, names = NULL, horizontals = TRUE, xlim = NULL)A ggplot object.
A list of fits of class fitdist or fitdistcens
computed from the same toxicity data.
A character vector, the unit of the toxicity data
if TRUE, uses a logarithmic scale for the \(x\)-axis
Label vector for data points (only for non censored data)
If TRUE, draws horizontal lines for the step empirical
cumulative distribution function (ecdf). See also plot.stepfun.
The \(x\)-limits of the plot.