Learn R Programming

ssd4mosaic (version 1.0.3)

combine_boot_samples: Combine several bootstrap samples into a single bootdist or bootdistcens object

Description

Combine several bootstrap samples into a single bootdist or bootdistcens object

Usage

combine_boot_samples(bs)

Value

A bootdist or bootdistcens object with a number of samples equal to the sum of number of samples of each bootstrap from the list input.

Arguments

bs

A list of bootdist or bootdistcens objects obtained from the same fit object.