Learn R Programming

ssd4mosaic (version 1.0.3)

fluazinam: 48-hour acute toxicity values for fluazinam

Description

48-hour acute toxicity values (EC50 values) for exposure of macroinvertebrates and zooplancton to fluazinam.

Usage

fluazinam

Arguments

Format

fluazinam

A data frame with 14 rows and 4 columns:

left, right

Lower & higher bounds of the effective concentration interval in \(\mu\)g/L.

name

Specie's name for each effective concentration.

group

Classification of the specie, not all rows use the same taxonomic rank.