Get HC5, HC10, HC20 and HC50 for each fit provided, with confidence intervals if the corresponding bootstraps were provided.
get_HCx_table(fits, distributions, bootstrap = NULL, CI.level = 0.95)A data.frame with different HCx as rows and different fits as columns.
A list of fits of class fitdist or fitdistcens
computed from the same toxicity data.
A list of the names of the distributions to apply (e.g.,
'lnorm', 'llogis')
A list of bootdist or bootdistcens objects
corresponding to the fits provided.
A numeric, either 0.95 or 0.9. The level of the confidence interval(s).