Get HCx corresponding to the provided x for each fit provided with confidence intervals
get_custom_HCx(x, distributions, bootstrap = NULL, CI.level = 0.95)A string describing the HCx and its confidence interval for each distribution.
An integer between 0 and 100.The percent of the hazardous concentration desired (HCx).
A list of the names of the distributions to apply (e.g.,
'lnorm', 'llogis')
A list of bootdist or bootdistcens objects
corresponding to the fits provided.
A numeric, either 0.95 or 0.9. The level of the confidence interval(s).