Learn R Programming

ssd4mosaic (version 1.0.3)

get_fits: Fit the specified distributions to the given data

Description

Fit the specified distributions to the given data

Usage

get_fits(data, distributions, censored)

Value

A list containing the fit object(s) of class fitdist or fitdistcens.

Arguments

data

If censored = TRUE, a data.frame with columns left and right. If censored = FALSE, a data.frame with a column conc.

distributions

A list of the names of the distributions to apply (e.g., 'lnorm', 'llogis')

censored

A Boolean, whether the given data is to be interpreted as censored