Learn R Programming

ssd4mosaic (version 1.0.3)

get_xlab: Create a label for x axis based on concentration unit and log scale

Description

Create a label for x axis based on concentration unit and log scale

Usage

get_xlab(unit, logscale)

Value

A character vector.

Arguments

unit

A character vector, the unit of the toxicity data

logscale

if TRUE, uses a logarithmic scale for the \(x\)-axis