Create an empirical cdf representation colored according to a "group" attribute. The fitted distribution is also represented.
group_cdf_censored(fits, unit, logscale, data)A ggplot object.
A list of fits of class fitdist or fitdistcens
computed from the same toxicity data.
A character vector, the unit of the toxicity data
if TRUE, uses a logarithmic scale for the \(x\)-axis
A data.frame with columns left, right and
group
The plot represents each interval of toxicity values with a horizontal line,
or a point if the bounds of the interval are equal, using function
cens_lines_plot().