Learn R Programming

ssd4mosaic (version 1.0.3)

group_cdf_uncensored: Graphical representation of grouped toxicity uncensored data

Description

Add a group coloration to a provided empirical cdf representation according to a "group" column in data.

Usage

group_cdf_uncensored(data, p)

Value

A ggplot object.

Arguments

data

A data.frame with columns conc and group.

p

a ggplot object showing the empirical cumulative distribution function of the uncensored data provided.