Create an empirical cumulative distribution function ggplot with a name (i.e. species names) associated to each observation.
name_plot_uncensored(fits, unit, logscale, data, horizontals = TRUE)A ggplot object.
A list of fits of class fitdist or fitdistcens
computed from the same toxicity data.
A character vector, the unit of the toxicity data
if TRUE, uses a logarithmic scale for the \(x\)-axis
A data.frame with column conc if uncensored data, with
left and right if censored data. In any case, must contain a
column name.
If TRUE, draws horizontal lines for the step empirical
cumulative distribution function (ecdf). See also plot.stepfun.