Learn R Programming

ssd4mosaic (version 1.0.3)

order_cens_data: Take a data.frame of censored toxicity data and order them like fitdistrplus plots

Description

Take a data.frame of censored toxicity data and order them like fitdistrplus plots

Usage

order_cens_data(data)

Value

A data.frame with ordered toxicity values.

Arguments

data

A data.frame of censored data with columns left and right