Learn R Programming

ssd4mosaic (version 1.0.3)

test_conv: Test the approximate equality of the quantiles from several bootstrap samples

Description

Test the approximate equality of the quantiles from several bootstrap samples

Usage

test_conv(bs, probs)

Value

A logical.

Arguments

bs

A list of bootdist or bootdistcens objects obtained from the same fit object.

probs

A numeric vector of probabilities with values in [0,1]