bootdist_fun: Determines the appropriate bootstrap function based on a fit object
Description
Determines the appropriate bootstrap function based on a fit object
Usage
bootdist_fun(x, ft, niter = 200)
Value
An appropriate bootstrap function.
Arguments
- x
Not used
- ft
A fitdist or fitdistcens object
- niter
An integer. The number of iterations set for the bootstrap
function