powered by
bootdist
bootdistcens
Combine several bootstrap samples into a single bootdist or bootdistcens object
combine_boot_samples(bs)
A bootdist or bootdistcens object with a number of samples equal to the sum of number of samples of each bootstrap from the list input.
A list of bootdist or bootdistcens objects obtained from the same fit object.