Fit the specified distributions to the given data
get_fits(data, distributions, censored)A list containing the fit object(s) of class fitdist or
fitdistcens.
If censored = TRUE, a data.frame with columns left
and right. If censored = FALSE, a data.frame with a column
conc.
A list of the names of the distributions to apply (e.g.,
'lnorm', 'llogis')
A Boolean, whether the given data is to be interpreted as censored