powered by
Create a label for x axis based on concentration unit and log scale
get_xlab(unit, logscale)
A character vector.
A character vector, the unit of the toxicity data
if TRUE, uses a logarithmic scale for the \(x\)-axis
TRUE