powered by
fitdistrplus
Take a data.frame of censored toxicity data and order them like fitdistrplus plots
order_cens_data(data)
A data.frame with ordered toxicity values.
A data.frame of censored data with columns left and right
left
right