powered by
Test the approximate equality of the quantiles from several bootstrap samples
test_conv(bs, probs)
A logical.
A list of bootdist or bootdistcens objects obtained from the same fit object.
bootdist
bootdistcens
A numeric vector of probabilities with values in [0,1]